using JLFzf
using Test

@testset "Fzf.jl" begin
    # Write your tests here.
end
